Class: Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2FieldAppliedCapabilities

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drivelabels_v2/classes.rb,
lib/google/apis/drivelabels_v2/representations.rb,
lib/google/apis/drivelabels_v2/representations.rb

Overview

The capabilities related to this field on applied metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsDriveLabelsV2FieldAppliedCapabilities

Returns a new instance of GoogleAppsDriveLabelsV2FieldAppliedCapabilities.



1470
1471
1472
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 1470

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#can_readBoolean Also known as: can_read?

Whether the user can read related applied metadata on items. Corresponds to the JSON property canRead

Returns:

  • (Boolean)


1455
1456
1457
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 1455

def can_read
  @can_read
end

#can_searchBoolean Also known as: can_search?

Whether the user can search for Drive items referencing this field. Corresponds to the JSON property canSearch

Returns:

  • (Boolean)


1461
1462
1463
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 1461

def can_search
  @can_search
end

#can_writeBoolean Also known as: can_write?

Whether the user can set this field on Drive items. Corresponds to the JSON property canWrite

Returns:

  • (Boolean)


1467
1468
1469
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 1467

def can_write
  @can_write
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1475
1476
1477
1478
1479
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 1475

def update!(**args)
  @can_read = args[:can_read] if args.key?(:can_read)
  @can_search = args[:can_search] if args.key?(:can_search)
  @can_write = args[:can_write] if args.key?(:can_write)
end