Class: Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2FieldSelectionOptionsChoiceDisplayHints
- Inherits:
-
Object
- Object
- Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2FieldSelectionOptionsChoiceDisplayHints
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drivelabels_v2/classes.rb,
lib/google/apis/drivelabels_v2/representations.rb,
lib/google/apis/drivelabels_v2/representations.rb
Overview
UI display hints for rendering an option.
Instance Attribute Summary collapse
-
#badge_colors ⇒ Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2BadgeColors
The color derived from BadgeConfig and changed to the closest recommended supported color.
-
#badge_priority ⇒ Fixnum
The priority of this badge.
-
#dark_badge_colors ⇒ Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2BadgeColors
The color derived from BadgeConfig and changed to the closest recommended supported color.
-
#disabled ⇒ Boolean
(also: #disabled?)
Whether the option should be shown in the UI as disabled.
-
#hidden_in_search ⇒ Boolean
(also: #hidden_in_search?)
This option should be hidden in the search menu when searching for Drive items.
-
#shown_in_apply ⇒ Boolean
(also: #shown_in_apply?)
This option should be shown in the apply menu when applying values to a Drive item.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2FieldSelectionOptionsChoiceDisplayHints
constructor
A new instance of GoogleAppsDriveLabelsV2FieldSelectionOptionsChoiceDisplayHints.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2FieldSelectionOptionsChoiceDisplayHints
Returns a new instance of GoogleAppsDriveLabelsV2FieldSelectionOptionsChoiceDisplayHints.
1987 1988 1989 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 1987 def initialize(**args) update!(**args) end |
Instance Attribute Details
#badge_colors ⇒ Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2BadgeColors
The color derived from BadgeConfig and changed to the closest recommended
supported color.
Corresponds to the JSON property badgeColors
1951 1952 1953 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 1951 def badge_colors @badge_colors end |
#badge_priority ⇒ Fixnum
The priority of this badge. Used to compare and sort between multiple badges.
A lower number means the badge should be shown first. When a badging
configuration is not present, this will be 0. Otherwise, this will be set to
BadgeConfig.priority_override or the default heuristic which prefers creation
date of the label, and field and option priority.
Corresponds to the JSON property badgePriority
1960 1961 1962 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 1960 def badge_priority @badge_priority end |
#dark_badge_colors ⇒ Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2BadgeColors
The color derived from BadgeConfig and changed to the closest recommended
supported color.
Corresponds to the JSON property darkBadgeColors
1966 1967 1968 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 1966 def dark_badge_colors @dark_badge_colors end |
#disabled ⇒ Boolean Also known as: disabled?
Whether the option should be shown in the UI as disabled.
Corresponds to the JSON property disabled
1971 1972 1973 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 1971 def disabled @disabled end |
#hidden_in_search ⇒ Boolean Also known as:
This option should be hidden in the search menu when searching for Drive items.
Corresponds to the JSON property hiddenInSearch
1977 1978 1979 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 1977 def hidden_in_search @hidden_in_search end |
#shown_in_apply ⇒ Boolean Also known as: shown_in_apply?
This option should be shown in the apply menu when applying values to a Drive
item.
Corresponds to the JSON property shownInApply
1984 1985 1986 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 1984 def shown_in_apply @shown_in_apply end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1992 1993 1994 1995 1996 1997 1998 1999 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 1992 def update!(**args) @badge_colors = args[:badge_colors] if args.key?(:badge_colors) @badge_priority = args[:badge_priority] if args.key?(:badge_priority) @dark_badge_colors = args[:dark_badge_colors] if args.key?(:dark_badge_colors) @disabled = args[:disabled] if args.key?(:disabled) @hidden_in_search = args[:hidden_in_search] if args.key?(:hidden_in_search) @shown_in_apply = args[:shown_in_apply] if args.key?(:shown_in_apply) end |