Class: Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2FieldTextOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drivelabels_v2/classes.rb,
lib/google/apis/drivelabels_v2/representations.rb,
lib/google/apis/drivelabels_v2/representations.rb

Overview

Options for the Text field type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsDriveLabelsV2FieldTextOptions

Returns a new instance of GoogleAppsDriveLabelsV2FieldTextOptions.



2095
2096
2097
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2095

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_lengthFixnum

Output only. The maximum valid length of values for the text field. Corresponds to the JSON property maxLength

Returns:

  • (Fixnum)


2088
2089
2090
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2088

def max_length
  @max_length
end

#min_lengthFixnum

Output only. The minimum valid length of values for the text field. Corresponds to the JSON property minLength

Returns:

  • (Fixnum)


2093
2094
2095
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2093

def min_length
  @min_length
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2100
2101
2102
2103
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2100

def update!(**args)
  @max_length = args[:max_length] if args.key?(:max_length)
  @min_length = args[:min_length] if args.key?(:min_length)
end