Class: Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2Label

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drivelabels_v2/classes.rb,
lib/google/apis/drivelabels_v2/representations.rb,
lib/google/apis/drivelabels_v2/representations.rb

Overview

A label defines a taxonomy that can be applied to Drive items in order to organize and search across items. Labels can be simple strings, or can contain fields that describe additional metadata that can be further used to organize and search Drive items.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsDriveLabelsV2Label

Returns a new instance of GoogleAppsDriveLabelsV2Label.



2295
2296
2297
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2295

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applied_capabilitiesGoogle::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2LabelAppliedCapabilities

The capabilities a user has on this label's applied metadata. Corresponds to the JSON property appliedCapabilities



2160
2161
2162
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2160

def applied_capabilities
  @applied_capabilities
end

#applied_label_policyGoogle::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2LabelAppliedLabelPolicy

Behavior of this label when it's applied to Drive items. Corresponds to the JSON property appliedLabelPolicy



2165
2166
2167
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2165

def applied_label_policy
  @applied_label_policy
end

#create_timeString

Output only. The time this label was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2170
2171
2172
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2170

def create_time
  @create_time
end

#creatorGoogle::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2UserInfo

Information about a user. Corresponds to the JSON property creator



2175
2176
2177
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2175

def creator
  @creator
end

#customerString

Output only. The customer this label belongs to. For example: customers/ 123abc789. Corresponds to the JSON property customer

Returns:

  • (String)


2181
2182
2183
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2181

def customer
  @customer
end

#disable_timeString

Output only. The time this label was disabled. This value has no meaning when the label isn't disabled. Corresponds to the JSON property disableTime

Returns:

  • (String)


2187
2188
2189
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2187

def disable_time
  @disable_time
end

#disablerGoogle::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2UserInfo

Information about a user. Corresponds to the JSON property disabler



2192
2193
2194
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2192

def disabler
  @disabler
end

#display_hintsGoogle::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2LabelDisplayHints

The UI display hints for rendering the label. Corresponds to the JSON property displayHints



2197
2198
2199
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2197

def display_hints
  @display_hints
end

#enabled_app_settingsGoogle::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2LabelEnabledAppSettings

Describes the Google Workspace apps in which the label can be used. Corresponds to the JSON property enabledAppSettings



2202
2203
2204
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2202

def enabled_app_settings
  @enabled_app_settings
end

#fieldsArray<Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2Field>

List of fields in descending priority order. Corresponds to the JSON property fields



2207
2208
2209
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2207

def fields
  @fields
end

#idString

Output only. Globally unique identifier of this label. ID makes up part of the label name, but unlike name, ID is consistent between revisions. Matches the regex: ([a-zA-Z0-9])+. Corresponds to the JSON property id

Returns:

  • (String)


2214
2215
2216
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2214

def id
  @id
end

#label_typeString

Required. The type of label. Corresponds to the JSON property labelType

Returns:

  • (String)


2219
2220
2221
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2219

def label_type
  @label_type
end

#learn_more_uriString

Custom URL to present to users to allow them to learn more about this label and how it should be used. Corresponds to the JSON property learnMoreUri

Returns:

  • (String)


2225
2226
2227
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2225

def learn_more_uri
  @learn_more_uri
end

#lifecycleGoogle::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2Lifecycle

The lifecycle state of an object, such as label, field, or choice. For more information, see Label lifecycle. The lifecycle enforces the following transitions: * UNPUBLISHED_DRAFT (starting state) * UNPUBLISHED_DRAFT -> PUBLISHED * UNPUBLISHED_DRAFT -> (Deleted) * PUBLISHED -> DISABLED * DISABLED -> PUBLISHED * DISABLED -> (Deleted) The published and disabled states have some distinct characteristics: * Published: Some kinds of changes might be made to an object in this state, in which case has_unpublished_changes will be true. Also, some kinds of changes aren't permitted. Generally, any change that would invalidate or cause new restrictions on existing metadata related to the label are rejected. * Disabled: When disabled, the configured DisabledPolicy takes effect. Corresponds to the JSON property lifecycle



2241
2242
2243
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2241

def lifecycle
  @lifecycle
end

#lock_statusGoogle::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2LockStatus

Contains information about whether a label component should be considered locked. Corresponds to the JSON property lockStatus



2247
2248
2249
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2247

def lock_status
  @lock_status
end

#nameString

Output only. Resource name of the label. Will be in the form of either: labels/idor `labels/`id`@`revision_id depending on the request. See id and revision_id below. Corresponds to the JSON property name

Returns:

  • (String)


2254
2255
2256
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2254

def name
  @name
end

#propertiesGoogle::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2LabelProperties

Basic properties of the label. Corresponds to the JSON property properties



2259
2260
2261
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2259

def properties
  @properties
end

#publish_timeString

Output only. The time this label was published. This value has no meaning when the label isn't published. Corresponds to the JSON property publishTime

Returns:

  • (String)


2265
2266
2267
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2265

def publish_time
  @publish_time
end

#publisherGoogle::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2UserInfo

Information about a user. Corresponds to the JSON property publisher



2270
2271
2272
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2270

def publisher
  @publisher
end

#revision_create_timeString

Output only. The time this label revision was created. Corresponds to the JSON property revisionCreateTime

Returns:

  • (String)


2275
2276
2277
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2275

def revision_create_time
  @revision_create_time
end

#revision_creatorGoogle::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2UserInfo

Information about a user. Corresponds to the JSON property revisionCreator



2280
2281
2282
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2280

def revision_creator
  @revision_creator
end

#revision_idString

Output only. Revision ID of the label. Revision ID might be part of the label name depending on the request issued. A new revision is created whenever revisioned properties of a label are changed. Matches the regex: ([a-zA-Z0-9]) +. Corresponds to the JSON property revisionId

Returns:

  • (String)


2288
2289
2290
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2288

def revision_id
  @revision_id
end

#schema_capabilitiesGoogle::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2LabelSchemaCapabilities

The capabilities related to this label when editing the label. Corresponds to the JSON property schemaCapabilities



2293
2294
2295
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2293

def schema_capabilities
  @schema_capabilities
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2300

def update!(**args)
  @applied_capabilities = args[:applied_capabilities] if args.key?(:applied_capabilities)
  @applied_label_policy = args[:applied_label_policy] if args.key?(:applied_label_policy)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creator = args[:creator] if args.key?(:creator)
  @customer = args[:customer] if args.key?(:customer)
  @disable_time = args[:disable_time] if args.key?(:disable_time)
  @disabler = args[:disabler] if args.key?(:disabler)
  @display_hints = args[:display_hints] if args.key?(:display_hints)
  @enabled_app_settings = args[:enabled_app_settings] if args.key?(:enabled_app_settings)
  @fields = args[:fields] if args.key?(:fields)
  @id = args[:id] if args.key?(:id)
  @label_type = args[:label_type] if args.key?(:label_type)
  @learn_more_uri = args[:learn_more_uri] if args.key?(:learn_more_uri)
  @lifecycle = args[:lifecycle] if args.key?(:lifecycle)
  @lock_status = args[:lock_status] if args.key?(:lock_status)
  @name = args[:name] if args.key?(:name)
  @properties = args[:properties] if args.key?(:properties)
  @publish_time = args[:publish_time] if args.key?(:publish_time)
  @publisher = args[:publisher] if args.key?(:publisher)
  @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time)
  @revision_creator = args[:revision_creator] if args.key?(:revision_creator)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
  @schema_capabilities = args[:schema_capabilities] if args.key?(:schema_capabilities)
end