Class: Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2LabelEnabledAppSettings
- Inherits:
-
Object
- Object
- Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2LabelEnabledAppSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drivelabels_v2/classes.rb,
lib/google/apis/drivelabels_v2/representations.rb,
lib/google/apis/drivelabels_v2/representations.rb
Overview
Describes the Google Workspace apps in which the label can be used.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2LabelEnabledAppSettings
constructor
A new instance of GoogleAppsDriveLabelsV2LabelEnabledAppSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2LabelEnabledAppSettings
Returns a new instance of GoogleAppsDriveLabelsV2LabelEnabledAppSettings.
2431 2432 2433 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2431 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled_apps ⇒ Array<Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2LabelEnabledAppSettingsEnabledApp>
Optional. The list of apps where the label can be used.
Corresponds to the JSON property enabledApps
2429 2430 2431 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2429 def enabled_apps @enabled_apps end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2436 2437 2438 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2436 def update!(**args) @enabled_apps = args[:enabled_apps] if args.key?(:enabled_apps) end |