Class: Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2LifecycleDisabledPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drivelabels_v2/classes.rb,
lib/google/apis/drivelabels_v2/representations.rb,
lib/google/apis/drivelabels_v2/representations.rb

Overview

The policy that governs how to treat a disabled label, field, or selection choice in different contexts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsDriveLabelsV2LifecycleDisabledPolicy

Returns a new instance of GoogleAppsDriveLabelsV2LifecycleDisabledPolicy.



2792
2793
2794
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2792

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hide_in_searchBoolean Also known as: hide_in_search?

Whether to hide this disabled object in the search menu for Drive items. * When false, the object is generally shown in the UI as disabled but it appears in the search results when searching for Drive items. * When true, the object is generally hidden in the UI when searching for Drive items. Corresponds to the JSON property hideInSearch

Returns:

  • (Boolean)


2781
2782
2783
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2781

def hide_in_search
  @hide_in_search
end

#show_in_applyBoolean Also known as: show_in_apply?

Whether to show this disabled object in the apply menu on Drive items. * When true, the object is generally shown in the UI as disabled and is unselectable.

  • When false, the object is generally hidden in the UI. Corresponds to the JSON property showInApply

Returns:

  • (Boolean)


2789
2790
2791
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2789

def show_in_apply
  @show_in_apply
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2797
2798
2799
2800
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2797

def update!(**args)
  @hide_in_search = args[:hide_in_search] if args.key?(:hide_in_search)
  @show_in_apply = args[:show_in_apply] if args.key?(:show_in_apply)
end