Class: Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2LockStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drivelabels_v2/classes.rb,
lib/google/apis/drivelabels_v2/representations.rb,
lib/google/apis/drivelabels_v2/representations.rb

Overview

Contains information about whether a label component should be considered locked.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsDriveLabelsV2LockStatus

Returns a new instance of GoogleAppsDriveLabelsV2LockStatus.



2910
2911
2912
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2910

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#lockedBoolean Also known as: locked?

Output only. Indicates whether this label component is the (direct) target of a label lock. A label component can be implicitly locked even if it's not the direct target of a label lock, in which case this field is set to false. Corresponds to the JSON property locked

Returns:

  • (Boolean)


2907
2908
2909
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2907

def locked
  @locked
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2915
2916
2917
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2915

def update!(**args)
  @locked = args[:locked] if args.key?(:locked)
end