Class: Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2LongTextLimits
- Inherits:
-
Object
- Object
- Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2LongTextLimits
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drivelabels_v2/classes.rb,
lib/google/apis/drivelabels_v2/representations.rb,
lib/google/apis/drivelabels_v2/representations.rb
Overview
Limits for long text field type.
Instance Attribute Summary collapse
-
#max_length ⇒ Fixnum
Maximum length allowed for a long text field type.
-
#min_length ⇒ Fixnum
Minimum length allowed for a long text field type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2LongTextLimits
constructor
A new instance of GoogleAppsDriveLabelsV2LongTextLimits.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2LongTextLimits
Returns a new instance of GoogleAppsDriveLabelsV2LongTextLimits.
2934 2935 2936 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2934 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_length ⇒ Fixnum
Maximum length allowed for a long text field type.
Corresponds to the JSON property maxLength
2927 2928 2929 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2927 def max_length @max_length end |
#min_length ⇒ Fixnum
Minimum length allowed for a long text field type.
Corresponds to the JSON property minLength
2932 2933 2934 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2932 def min_length @min_length end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2939 2940 2941 2942 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2939 def update!(**args) @max_length = args[:max_length] if args.key?(:max_length) @min_length = args[:min_length] if args.key?(:min_length) end |