Class: Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2PublishLabelRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drivelabels_v2/classes.rb,
lib/google/apis/drivelabels_v2/representations.rb,
lib/google/apis/drivelabels_v2/representations.rb

Overview

Request to publish a label.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsDriveLabelsV2PublishLabelRequest

Returns a new instance of GoogleAppsDriveLabelsV2PublishLabelRequest.



2968
2969
2970
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2968

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#language_codeString

The BCP-47 language code to use for evaluating localized field labels. When not specified, values in the default configured language will be used. Corresponds to the JSON property languageCode

Returns:

  • (String)


2953
2954
2955
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2953

def language_code
  @language_code
end

#use_admin_accessBoolean Also known as: use_admin_access?

Set to true in order to use the user's admin credentials. The server will verify the user is an admin for the label before allowing access. Corresponds to the JSON property useAdminAccess

Returns:

  • (Boolean)


2959
2960
2961
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2959

def use_admin_access
  @use_admin_access
end

#write_controlGoogle::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2WriteControl

Provides control over how write requests are executed. When not specified, the last write wins. Corresponds to the JSON property writeControl



2966
2967
2968
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2966

def write_control
  @write_control
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2973
2974
2975
2976
2977
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2973

def update!(**args)
  @language_code = args[:language_code] if args.key?(:language_code)
  @use_admin_access = args[:use_admin_access] if args.key?(:use_admin_access)
  @write_control = args[:write_control] if args.key?(:write_control)
end