Class: Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2UpdateLabelPermissionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drivelabels_v2/classes.rb,
lib/google/apis/drivelabels_v2/representations.rb,
lib/google/apis/drivelabels_v2/representations.rb

Overview

Updates a label permission. Permissions affect the label resource as a whole, aren't revisioned, and don't require publishing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsDriveLabelsV2UpdateLabelPermissionRequest

Returns a new instance of GoogleAppsDriveLabelsV2UpdateLabelPermissionRequest.



3156
3157
3158
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 3156

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#label_permissionGoogle::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2LabelPermission

The permission that applies to a principal (user, group, audience) on a label. Corresponds to the JSON property labelPermission



3142
3143
3144
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 3142

def label_permission
  @label_permission
end

#parentString

Required. The parent label resource name. Corresponds to the JSON property parent

Returns:

  • (String)


3147
3148
3149
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 3147

def parent
  @parent
end

#use_admin_accessBoolean Also known as: use_admin_access?

Set to true in order to use the user's admin credentials. The server will verify the user is an admin for the label before allowing access. Corresponds to the JSON property useAdminAccess

Returns:

  • (Boolean)


3153
3154
3155
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 3153

def use_admin_access
  @use_admin_access
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3161
3162
3163
3164
3165
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 3161

def update!(**args)
  @label_permission = args[:label_permission] if args.key?(:label_permission)
  @parent = args[:parent] if args.key?(:parent)
  @use_admin_access = args[:use_admin_access] if args.key?(:use_admin_access)
end