Class: Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2LabelLimits
- Inherits:
-
Object
- Object
- Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2LabelLimits
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drivelabels_v2/classes.rb,
lib/google/apis/drivelabels_v2/representations.rb,
lib/google/apis/drivelabels_v2/representations.rb
Overview
Label constraints governing the structure of a label; such as, the maximum number of fields allowed and maximum length of the label title.
Instance Attribute Summary collapse
-
#field_limits ⇒ Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2FieldLimits
Field constants governing the structure of a field; such as, the maximum title length, minimum and maximum field values or length, etc.
-
#max_deleted_fields ⇒ Fixnum
The maximum number of published fields that can be deleted.
-
#max_description_length ⇒ Fixnum
The maximum number of characters allowed for the description.
-
#max_draft_revisions ⇒ Fixnum
The maximum number of draft revisions that will be kept before deleting old drafts.
-
#max_fields ⇒ Fixnum
The maximum number of fields allowed within the label.
-
#max_title_length ⇒ Fixnum
The maximum number of characters allowed for the title.
-
#name ⇒ String
Resource name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2LabelLimits
constructor
A new instance of GoogleAppsDriveLabelsV2LabelLimits.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsDriveLabelsV2LabelLimits
Returns a new instance of GoogleAppsDriveLabelsV2LabelLimits.
2502 2503 2504 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2502 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field_limits ⇒ Google::Apis::DrivelabelsV2::GoogleAppsDriveLabelsV2FieldLimits
Field constants governing the structure of a field; such as, the maximum title
length, minimum and maximum field values or length, etc.
Corresponds to the JSON property fieldLimits
2469 2470 2471 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2469 def field_limits @field_limits end |
#max_deleted_fields ⇒ Fixnum
The maximum number of published fields that can be deleted.
Corresponds to the JSON property maxDeletedFields
2474 2475 2476 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2474 def max_deleted_fields @max_deleted_fields end |
#max_description_length ⇒ Fixnum
The maximum number of characters allowed for the description.
Corresponds to the JSON property maxDescriptionLength
2479 2480 2481 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2479 def max_description_length @max_description_length end |
#max_draft_revisions ⇒ Fixnum
The maximum number of draft revisions that will be kept before deleting old
drafts.
Corresponds to the JSON property maxDraftRevisions
2485 2486 2487 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2485 def max_draft_revisions @max_draft_revisions end |
#max_fields ⇒ Fixnum
The maximum number of fields allowed within the label.
Corresponds to the JSON property maxFields
2490 2491 2492 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2490 def max_fields @max_fields end |
#max_title_length ⇒ Fixnum
The maximum number of characters allowed for the title.
Corresponds to the JSON property maxTitleLength
2495 2496 2497 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2495 def max_title_length @max_title_length end |
#name ⇒ String
Resource name.
Corresponds to the JSON property name
2500 2501 2502 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2500 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2507 2508 2509 2510 2511 2512 2513 2514 2515 |
# File 'lib/google/apis/drivelabels_v2/classes.rb', line 2507 def update!(**args) @field_limits = args[:field_limits] if args.key?(:field_limits) @max_deleted_fields = args[:max_deleted_fields] if args.key?(:max_deleted_fields) @max_description_length = args[:max_description_length] if args.key?(:max_description_length) @max_draft_revisions = args[:max_draft_revisions] if args.key?(:max_draft_revisions) @max_fields = args[:max_fields] if args.key?(:max_fields) @max_title_length = args[:max_title_length] if args.key?(:max_title_length) @name = args[:name] if args.key?(:name) end |